if 0 {
 We will make a frame-like widget that has a master image per-toplevel or frame.  This master image should grow to fit the canvas that displays it.  The subwindows of the frame-like widget (based on a canvas), such as a label widget will need to use [winfo x] and [winfo y] to calculate the area of the master image that they should copy.  Each label widget will need an image variable that is deleted and recreated on <Configure>.

What should we call our frame-like widget?  How about PhotoFrame?  

What should we call our label widget?  PhotoLabel

#case 1 ( a simple menubar with a background image ) 
 set img [image create photo ...]
 #our menubar frame
 pack [PhotoFrame .mbf] -fill x
 .mbf image $img
 pack [menubutton .mbf.file -text File] -side left

#case 2 ( a frame with subwidgets and PhotoLabels )

 set img [image create photo ...]
 text .t
 PhotoFrame .f
 grid .t .f

 pack [PhotoLabel .f.info -text {Commands:} -photo_parent .f] 
 pack [button .f.copy -text Copy]
 pack [button .f.paste -text Paste]
 pack [button .f.cut -text Cut]
 pack [button .f.clear -text Clear]
 .f image $img

PhotoLabel should call call [winfo parent] and add the [winfo x] and [winfo y] until it reaches .f.  This will give us a valid offset.  Then it will copy the [.f image] to a private image for the PhotoLabel alone.


So:
 PhotoFrame $win
 $win image $img

 PhotoLabel $win ?-text -photo_parent?
 $win config ?-text -photo_parent?


Methods:
 PhotoFrame 
  ->create.tiled.image ( tiles an existing image until it fills [winfo width/height] )
  ->draw.tiled.image ( calls $win create image and stores the id returned )
  ->event.configure ( create.tiled.image and call draw.tiled.image )
  ->event.destroy ( free the image if $win == %W ) 
  ->instance.handler ( handle image subcmd )
 
 PhotoLabel
  ->calculate.parent.offset
  ->draw.background ( image delete existing background.  It should raise the text above the image and store the id of the background )
  ->event.configure ( calls calculate.parent.offset and sends the results to draw.background )
  ->event.destroy ( free the image if $win == %W )
  ->instance.handler ( handle config cget and so on )

}

#BEGIN unplanned sources (prototype before plans above)
package require Tk
proc mk.image {} {
 #set maxX [winfo screenwidth .]
 #set maxY [winfo screenheight .]
 set maxX 200
 set maxY 200
 set img [image create photo -width $maxX -height $maxY]

 set lightImg [image create photo -width 40 -height 40]
 $lightImg put gray70 -to 0 0 40 40 
 
 set darkImg [image create photo -width 40 -height 40]
 $darkImg put gray40 -to 0 0 40 40

 set count 0
 for {set y 0} {$y < $maxY} {incr y 40} {
  for {set x 0} {$x < $maxX} {incr x 40} {
   set x2 [expr {$x + 40}]
   set y2 [expr {$y + 40}]
   if {$count & 1} {
    $img copy $lightImg -to $x $y $x2 $y2
   } else {
    $img copy $darkImg -to $x $y $x2 $y2
   }
   incr count
  }
 }
 return $img
}

proc cframe win {
 canvas $win -width 200 -height 200
 return $win
}

proc tlabel {win txt img} {
 set fnt {Helvetica 12}
 set w [font measure $fnt $txt]
 array set fm [font metrics $fnt]
 set h [expr {$fm(-linespace) + 2}]
 canvas $win -bd 0 -highlightthickness 0
 $win create text [expr {$w / 2}] [expr {$h / 2}] -text $txt -tags text
 $win config -width $w -height $h

 bind $win <Configure> [list tlabel.event.configure $win $img]
 return $win
}

set tmp {}
proc tlabel.event.configure {win img} {
 global tmp
 puts CONF
 $win delete pixmap
 set w [winfo width $win]
 set h [winfo height $win]

 if {"" != $tmp} {
  image delete $tmp
 }
 set tmp [image create photo -width $w -height $h]
 set x [winfo x $win]
 set y [winfo y $win]
 set x2 [expr {$x + [winfo width $win]}]
 set y2 [expr {$y + [winfo height $win]}]
 $tmp copy $img -from $x $y $x2 $y2
 $win create image [expr {$w / 2}] [expr {$h / 2}] -image $tmp -tags pixmap
 $win raise text
}

proc main {} {
 set mimg [mk.image]
 pack propagate . 0
 pack [cframe .f] -fill both -expand 1
 place [tlabel .l Hello $mimg] -x 30 -y 40
 .f create image 100 100 -image $mimg
}
main
